@@ -11,6 +11,7 @@ import re
 import signal
 import sys
 import time
+import warnings
 
 import zmq
 
@@ -38,7 +39,7 @@ class KernelManager(ConnectionFileMixin):
     # The PyZMQ Context to use for communication with the kernel.
     context = Instance(zmq.Context)
     def _context_default(self):
-        return zmq.Context.instance()
+        return zmq.Context()
 
     # the class to create with our `client` method
     client_class = DottedObjectName('jupyter_client.blocking.BlockingKernelClient')
@@ -77,7 +78,7 @@ class KernelManager(ConnectionFileMixin):
 
     @property
     def kernel_spec(self):
-        if self._kernel_spec is None:
+        if self._kernel_spec is None and self.kernel_name is not '':
             self._kernel_spec = self.kernel_spec_manager.get_kernel_spec(self.kernel_name)
         return self._kernel_spec
 
@@ -229,9 +230,10 @@ class KernelManager(ConnectionFileMixin):
         """
         if self.transport == 'tcp' and not is_local_ip(self.ip):
             raise RuntimeError("Can only launch a kernel on a local interface. "
+                               "This one is not: %s."
                                "Make sure that the '*_address' attributes are "
                                "configured properly. "
-                               "Currently valid addresses are: %s" % local_ips()
+                               "Currently valid addresses are: %s" % (self.ip, local_ips())
                                )
 
         # write connection file / get default ports
